@@ -68,20 +68,24 @@ class Amplitude():
     def clean_event(self, event: dict) -> dict:
         for key, value in event.items():
             if isinstance(value, dict):
-                event[key] = {k: v for k, v in value.items() if v is not [None, [], '', {}]}  # NOQA: E501
+                event[key] = {k: v for k, v in value.items() if v not in [None, [], '', {}]}  # NOQA: E501race()
 
         event = {k: v for k, v in event.items() if v not in [None, [], '', {}]}
 
         return event
 
     def build_event_data(
-        self, event_type: str, request: HttpRequest, **kwargs
+        self, event_type: str,
+        request: HttpRequest,
+        event_properties: dict = {},
+        **kwargs
     ) -> dict:
         """
         Build event data using a Django request object
         """
         event: Dict[str, Any] = {
             'device_id': request.session.get('amplitude_device_id'),
+            'session_id': request.session.get('amplitude_session_id'),
             'event_type': event_type,
             'time': int(round(time.time() * 1000)),
             'ip': get_client_ip(request),
@@ -101,19 +105,25 @@ class Amplitude():
             'event_id': kwargs.get('event_id'),
             'insert_id': kwargs.get('insert_id'),
         }
+
+        if event_properties:
+            event['event_properties'] = event_properties
+        else:
+            event['event_properties'] = self.event_properties_from_request(request)  # NOQA: E501
+
         try:
             event['user_id'] = f'{request.user.pk:05}'
         except (AttributeError, TypeError):
             pass
-
-        event['session_id'] = request.session.get('amplitude_session_id')
-        event['event_properties'] = self.event_properties_from_request(request)
         event['user_properties'] = self.user_properties_from_request(request)
         event['groups'] = self.group_from_request(request)
+
         device_data = self.device_data_from_request(request)
         event.update(device_data)
+
         location_data = self.location_data_from_ip_address(event['ip'])
         event.update(location_data)
+
         return event
 
     def event_properties_from_request(self, request: HttpRequest) -> dict:
@@ -123,6 +133,17 @@ class Amplitude():
             'url_name': url_name,
             'method': request.method,
             'params': dict(request.GET),
+            'scheme': request.scheme,
+            'content_type': request.content_type,
+            'content_params': request.content_params,
+            'content_length': request.META.get('CONTENT_LENGTH'),
+            'http_accept': request.META.get('HTTP_ACCEPT'),
+            'http_accept_encoding': request.META.get('HTTP_ACCEPT_ENCODING'),
+            'http_accept_language': request.META.get('HTTP_ACCEPT_LANGUAGE'),
+            'http_host': request.META.get('HTTP_HOST'),
+            'referer': request.META.get('HTTP_REFERER'),
+            'server_name': request.META.get('SERVER_NAME'),
+            'server_port': request.META.get('SERVER_PORT'),
         }
         if request.resolver_match:
             event_properties['kwargs'] = request.resolver_match.kwargs
@@ -140,15 +161,18 @@ class Amplitude():
         User = get_user_model()
         user = User.objects.get(pk=request.user.pk)
 
-        return {
+        user_data = {
             'username': user.get_username(),
             'email': user.email,
             'full_name': user.get_full_name(),
             'is_staff': user.is_staff,
             'is_superuser': user.is_superuser,
-            'last_login': user.last_login.isoformat(),
-            'date_joined': user.date_joined.isoformat(),
         }
+        if user.last_login:
+            user_data['last_login'] = user.last_login.isoformat()
+        if user.date_joined:
+            user_data['date_joined'] = user.date_joined.isoformat()
+        return user_data
 
     def group_from_request(self, request: HttpRequest) -> list:
         try:
